==> dialog_pp_flutter-1.0.2.tar.gz: README.md <==
## Add in void main

```dart   
await PPDialog.newVersionCode();
```

## Get Version Code Details

```dart 
    print(AppDetailsPP.to.appName.value);
    print(AppDetailsPP.to.packageName.value);
    print(AppDetailsPP.to.versionApp.value);
    print(AppDetailsPP.to.buildNumber.value); 
```

# Update Dialog

## Custom Update Dialog

```dart
        PPDialog.updateDialog(context,isPopupRequired: true
,
isPopup: true
,
apiVersionCode: 3
,
appLogoApi:"
https://play-lh.googleusercontent.com/c2DcVsBUhJb3UlAGABHwafpuhstHwORpVwWZ0RvWY7NPrgdtT2o4JRhcyO49ehhUNRca=w240-h480-rw
"
,
appNameApi: "
Instagram
"
,
subtitleAppApi:"
Share videos, photos, and fun moments with the friends you love
"
,
appWebsiteUrl:"
https://play.google.com/store/apps/details?id=com.instagram.android
"
,

);
```

## Auto Update Dialog

```dart
PPDialog.autoUpdate();
```

# Drawer

## drawer Api Call

```dart
await advertisementDrawerApi
(
"
enter more live url drawer api
"
);
```

## drawer ui

```dart
         PPDialog.drawerScreen(appLogo: "
"
,
privacyPolicy:"
"
,
feedbackEmailId: "
"
,
emailSubject: "
"
,
emailMessage:"
"
)
```

# Rate

## Auto Rate Dialog

```dart
    PPDialog.autoRate();
```

## Rate Dialog Custom

```dart
    PPDialog.rateDialogCustom(context,logoApp: "");
```

# Reward Dialog

```dart
    PPDialog.rewardDialog(
        rewardMessage: "Watch Reward ads for get IPTV list free",
        onTap: () {},
    );
);
```

# Exit Dialog

```dart
  PPDialog.exitDialog(
mediumNative: Container(
alignment: Alignment.center,
height: 170.h,
color: Colors.green[200],
child: Text("Medium Size Native Ad"),
),
appLogo: '');
```
![alt text](https://github.com/kp-bitcoding/ad-manager/blob/main/pragnesh_demo/exit_final.png?raw=true)

# Terms & Condition Dialog

```dart
          PPDialog.termsConditions(context,
                  privacyPolicyUrl: "",
                  termsConditionUrl: "",
                  isPrivacyPolicy: );
```

==> dialog_pp_flutter-1.0.3.tar.gz: README.md <==
## Add in void main

```dart   
await PPDialog.newVersionCode();
```

## Get Version Code Details

```dart 
    print(AppDetailsPP.to.appName.value);
    print(AppDetailsPP.to.packageName.value);
    print(AppDetailsPP.to.versionApp.value);
    print(AppDetailsPP.to.buildNumber.value); 
```

# Update Dialog

## Custom Update Dialog

```dart
        PPDialog.updateDialog(context,isPopupRequired: true
,
isPopup: true
,
apiVersionCode: 3
,
appLogoApi:"
https://play-lh.googleusercontent.com/c2DcVsBUhJb3UlAGABHwafpuhstHwORpVwWZ0RvWY7NPrgdtT2o4JRhcyO49ehhUNRca=w240-h480-rw
"
,
appNameApi: "
Instagram
"
,
subtitleAppApi:"
Share videos, photos, and fun moments with the friends you love
"
,
appWebsiteUrl:"
https://play.google.com/store/apps/details?id=com.instagram.android
"
,

);
```

## Auto Update Dialog

```dart
PPDialog.autoUpdate();
```

# Drawer

## drawer Api Call

```dart
await advertisementDrawerApi
(
"
enter more live url drawer api
"
);
```

## drawer ui

```dart
         PPDialog.drawerScreen(appLogo: "
"
,
privacyPolicy:"
"
,
feedbackEmailId: "
"
,
emailSubject: "
"
,
emailMessage:"
"
)
```

# Rate

## Auto Rate Dialog

```dart
    PPDialog.autoRate();
```

## Rate Dialog Custom

```dart
    PPDialog.rateDialogCustom(context,logoApp: "");
```

# Reward Dialog

```dart
    PPDialog.rewardDialog(
rewardMessage: "Watch Reward ads for get IPTV list free",
onTap: () {},
);
);
```

# Exit Dialog

```dart
  PPDialog.exitDialog(
mediumNative: Container(
alignment: Alignment.center,
height: 170.h,
color: Colors.green[200],
child: Text("Medium Size Native Ad"),
),
appLogo: '');
```
![alt text](https://github.com/kp-bitcoding/ad-manager/blob/main/pragnesh_demo/exit_final%20(1).png?raw=true)
# Terms & Condition Dialog

```dart
          PPDialog.termsConditions(context,
privacyPolicyUrl: "",
termsConditionUrl: "",
isPrivacyPolicy: );
```
